import { TestBed, async } from '@angular/core/testing';
import { HttpClientTestingModule, HttpTestingController } from '@angular/common/http/testing';
import { FndModule } from './fnd.module';
import { INTL_CONFIG } from './services/intl/intl.service';
import { GlobalService } from './services/global/global.service';

describe('Suite de testes do modulo: FndModule', () => {

  let global: GlobalService;
  let httpMock: HttpTestingController;

  const retJson = {
    'pt-br': { teste: 'testeautomatizado' },
    'en-us': { teste: 'automatedtest' }
  };

  const urlJson = './assets/translate.json';
  const urlJson2 = './assets/translate2.json';

  beforeEach(() => {

    TestBed.configureTestingModule({
      imports: [FndModule.forRoot(), HttpClientTestingModule],
      declarations: [],
      providers: [
        {
          provide: INTL_CONFIG,
          useValue: { url: urlJson }
        },
      ]
    });

    global = TestBed.get(GlobalService);
    httpMock = TestBed.get(HttpTestingController);

  });

  it('Servico global (globalService) deve estar carregado', () => {

    expect(global).toBeDefined();

  });

  it('Literais devem estar carregadas', () => {
    global.i18n.updateOptions({})
    .subscribe(x => {
      expect(global.i18n.literals).toBeDefined();
    });

  });

  it('Funcao para carregar literais chamada manualmente com sucesso', async( () => {

    global.i18n.updateOptions({url: urlJson2}).subscribe((literais) => {
      expect(literais.teste).toBe('testeautomatizado');
    });

    // Resolve a requisicao http da funcao 'carregarLiterais'
    const jsonRequestUpdate = httpMock.expectOne(urlJson2);
    jsonRequestUpdate.flush(retJson);

  }));

  it('Trocando idioma com sucesso', () => {

    global.i18n.updateOptions({ language: 'en-us' }).subscribe((literais) => {
      expect(literais.teste).toBe('automatedtest');
    });

  });

  it('Arquivo de traducao nao encontrado', () => {
    try {
      global.i18n.updateOptions({url: urlJson2})
      .subscribe((literais) => {
        expect(literais).toBeUndefined();
      }, ( error ) => {
        expect(error).toBeDefined();
      });
      // Resolve a requisicao http da funcao 'carregarLiterais'
      const jsonRequestUpdate = httpMock.expectOne(urlJson2);
      // jsonRequestUpdate.flush({message: 'my error message'}, {status: 404, statusText: 'Server error'});
      jsonRequestUpdate.error(new ErrorEvent('NOT_FOUND_ERROR'));
      httpMock.verify();
    } catch (e) {
      expect(e).toBeDefined();
    }
  });
});
