import { INTL_CONFIG } from './services/intl/intl.service';
import { MessageComponent } from './services/message/message.component';
import { MessageModule } from './services/message/message.module';
import { NgModule, ModuleWithProviders, APP_INITIALIZER } from '@angular/core';
import { ThfModule } from '@totvs/thf-ui';
import { IntlModule } from './services/intl/intl.module';
import { GlobalService } from './services/global/global.service';
import { LoadingModule } from './services/loading/loading.module';
import { LoadingComponent } from './services/loading/loading.component';
import { DateTimeModule, I18nBaseService } from 'totvs-log-base-foundation';
import { i18nFactory } from './services/intl/i18n-factory';

/**
 * Módulo que exporta e ativas as dependências basicas do foundation
 * Para garantir que os serviços tenham uma única instância, usar FndModule.forRoot() ao importar
 */
@NgModule({
  imports: [
    ThfModule,
    IntlModule,
    MessageModule,
    DateTimeModule,
    LoadingModule
  ],
  exports: [
    IntlModule,
    MessageModule,
    DateTimeModule,
    LoadingModule
  ],
  entryComponents: [MessageComponent, LoadingComponent]
})
export class FndModule {
  static forRoot(): ModuleWithProviders {
    return {
      ngModule: FndModule,
      providers: [
        GlobalService,
        {
          provide: APP_INITIALIZER,
          useFactory: i18nFactory,
          deps: [I18nBaseService, INTL_CONFIG],
          multi: true
        }
      ]
    };
  }
}
