import { AuthGuard } from './auth.guard';
import { AuthCallbackComponent } from './auth-callback.component';
import {
  AuthBaseService,
  AuthInterceptorHandlerService,
  UserPermissionService
} from 'totvs-log-base-foundation';
import { AuthService } from './auth.service';
import { ModuleWithProviders, NgModule } from '@angular/core';
import { HTTP_INTERCEPTORS } from '@angular/common/http';

/**
 * Módulo que exporta e ativas as dependências para utilizar autenticação com fluxo oauth2
 * Para garantir que os serviços tenham uma única instância, usar AuthModule.forRoot() ao importar
 */
@NgModule({
  imports: [],
  exports: [],
  entryComponents: [],
  providers: [
    {
      provide: HTTP_INTERCEPTORS,
      useClass: AuthInterceptorHandlerService,
      multi: true
    }
  ],
  declarations: [AuthCallbackComponent]
})
export class AuthModule {
  static forRoot(): ModuleWithProviders {
    return {
      ngModule: AuthModule,
      providers: [
        AuthService,
        UserPermissionService,
        {
          provide: AuthBaseService,
          useClass: AuthService
        },
        AuthGuard
      ]
    };
  }
}
