import { Injectable, InjectionToken, Inject } from '@angular/core';
import { ThfI18nConfig } from '@totvs/thf-ui';
import { I18nBaseService } from 'totvs-log-base-foundation';
import { IIntlConfig } from './intl-config.interface';
import { IntlLiteralsLoaderService } from './intl-literal-loader.service';

/**
 * Token de configuração da url de internacionalização
 */
export const INTL_CONFIG = new InjectionToken<IIntlConfig>('Configurações da internacionalização');

/**
 * Serviço de internacionalização
 */
@Injectable()
export class IntlService extends I18nBaseService {

  /**
   * Atributo com as configurações de internacionalização
   */
  public static i18nConfig: ThfI18nConfig = {
    contexts: {
    },
    default: {
      language: 'pt-br',
      context: 'general',
      cache: true
    }
  };

  /**
   * Método construtor da classe
   * @param config Parâmetro do serviço com as configurações de internacionalização
   * @param intlLiteralsLoader Parâmetro do serviço de carregamento de literais de internacionalização
   */
  constructor(
    @Inject(INTL_CONFIG) config: IIntlConfig,
    intlLiteralsLoader: IntlLiteralsLoaderService) {

    super(intlLiteralsLoader);

    let matchedAppLanguage;

    if (config.supportedLanguages) {
      matchedAppLanguage = config.supportedLanguages.find((appSupportedLanguage) => {
        return appSupportedLanguage.language === navigator.language;
      });
      matchedAppLanguage = matchedAppLanguage ? matchedAppLanguage : IntlService.i18nConfig.default.language;
    } else {
      matchedAppLanguage = IntlService.i18nConfig.default.language;
      config.supportedLanguages = [{
        language: IntlService.i18nConfig.default.language
      }];
    }

    this.updateOptions({
      context: IntlService.i18nConfig.default.context,
      language: matchedAppLanguage.language,
      url: config.url,
      supportedLanguages: config.supportedLanguages
    });
  }
}
